'''
unit tests for __init__.py
'''

from nose import tools as nt
import os

import helpers

import CFchecker
from CFchecker.errors import CFCheckerError, CFAutoDetectError

_tempdir = '/tmp/'

class initTests_test(object):
    faulty_file = os.path.join(_tempdir, 'tests_faulty_t2.nc')

    #
    #   setup and teardown
    #
    @classmethod
    def setup_class(cls):
        helpers.create_faulty_ncfile_cf10(cls.faulty_file)
    @classmethod
    def teardown_class(cls):
        os.remove(cls.faulty_file)

    # tests
    def test_get_available_versions(self):
        '''__init__: get_available_versions()'''
        versions = set(CFchecker.get_available_versions())
        expected = set(['auto'] + ['1.%d' % i for i in range(6)])
        nt.assert_equals(versions, expected)

    def test_checkfile_errors(self):
        '''__init__: checkfile() Exceptions'''
        # check auto detection fail
        nt.assert_raises(CFAutoDetectError, CFchecker.checkfile, self.faulty_file, 'auto')
        # check for unknown CF version
        try:
            CFchecker.checkfile(self.faulty_file, '5.x')
            raise Exception('CFCheckerError for unknown CF version not caught')
        except CFCheckerError, err:
            nt.assert_equals(str(err), 'unknown CF conventions version "5.x"')
